'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = graphPath;
// Render the svg path representing the graph's data.
function graphPath(selection, graphWidth, graphHeight, yScale, data) {
  // Generate the svg path for the graph line.
  var pathPrefix = 'M1,' + graphHeight + ('L1,' + yScale(initialCount)) + ('H' + xScale(normalize(dataStart)));
  var pathSuffix = 'H' + lastX + 'V' + graphHeight + 'H1';

  // Build the path by looping through the data.
  // For each point, move horizontally then vertically to the coordinate.
  var linePath = data.reduce(function (total, i) {
    var xPosition = xScale(normalize(i.timestamp));
    var yPosition = yScale(i.count);
    if (xPosition >= 0) {
      return total + 'H' + xPosition + 'V' + yPosition;
    } else {
      return total;
    }
  }, '');

  // Render the calculated svg path to the dom via a data join.
  var graphSelection = selection.selectAll('.graph-path').data([data]);

  // On enter, create two new paths: one to be used to create an outline and one to be used to fill
  // the contents 
  var graphEnterSelection = graphSelection.enter();
  graphEnterSelection.append('path').attr('class', 'graph-path');
  graphEnterSelection.append('path').attr('class', 'graph-path-outline');

  var graphMergeSelection = graphEnterSelection.merge(graphSelection);
  graphMergeSelection.select('.graph-path').attr('d', function (d) {
    return pathPrefix + linePath + pathSuffix;
  });
  graphMergeSelection.select('.graph-path-outline').attr('d', function (d) {
    return pathPrefix + linePath;
  });

  graphSelection.exit();
}

